Song

Struct Song 

pub struct Song {
    pub name: String,
    pub format: FormatDescription,
    pub samples: Vec<Sample>,
    pub patterns: Vec<Pattern>,
    pub pattern_table: Vec<u8>,
    pub num_used_patterns: u32,
    pub end_position: u32,
    pub has_standard_notes: bool,
}
Contains the entire mod song

Fields

name: String

The name of the song as specified in the mod file

format: FormatDescription

Features of the song

samples: Vec<Sample>

The audio samples used by the song

patterns: Vec<Pattern>

Patterns contain all the note data

pattern_table: Vec<u8>

Specifies the order in whcih the patterns should be played in. The same pattern may played several times in the same song

num_used_patterns: u32

How many patterns in the pattern table should be used. The pattern table is a fixed length can usually longer than the song

end_position: u32

Which pattern should be played after the last pattern in the pattern_table. Used for infinitely looping repeating songs

has_standard_notes: bool

Set to true if all the notes are standard notes (i.e. conforming to the standard period table)